summaryrefslogtreecommitdiff
path: root/src/leap/bitmask/vpn/vpn.py
diff options
context:
space:
mode:
authorRuben Pollan <meskio@sindominio.net>2017-03-17 00:44:00 +0100
committerRuben Pollan <meskio@sindominio.net>2017-03-17 19:13:23 +0100
commit1d09d1a079f8ce577de13ab43c2e9add7a6247bc (patch)
treea84d324912b13b68c9990a515267f0973cf289b3 /src/leap/bitmask/vpn/vpn.py
parent09bf881b4f457f731c5a49e88822bc731eda2c96 (diff)
[bug] let's remove hardcoded providers
Diffstat (limited to 'src/leap/bitmask/vpn/vpn.py')
-rw-r--r--src/leap/bitmask/vpn/vpn.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/leap/bitmask/vpn/vpn.py b/src/leap/bitmask/vpn/vpn.py
index dc3062af..5c9e46e3 100644
--- a/src/leap/bitmask/vpn/vpn.py
+++ b/src/leap/bitmask/vpn/vpn.py
@@ -25,10 +25,10 @@ from leap.bitmask.vpn.fw.firewall import FirewallManager
class VPNManager(object):
- def __init__(self, remotes, cert, key, ca, flags):
+ def __init__(self, provider, remotes, cert, key, ca, flags):
self._vpn = TunnelManager(
remotes, cert, key, ca, flags)
self._firewall = FirewallManager(remotes)
def start(self):
@@ -25,10 +25,10 @@ from leap.bitmask.vpn.fw.firewall import FirewallManager
self._vpn = TunnelManager(
- remotes, cert, key, ca, flags)
+ provider, remotes, cert, key, ca, flags)
self._firewall = FirewallManager(remotes)
def start(self):